@@ -2,6 +2,7 @@
 #include <config.h>
 #include "Imlib.h"
 #include "Imlib_private.h"
+#include <locale.h>
 
 #ifndef HAVE_SNPRINTF
 #define snprintf my_snprintf
@@ -179,6 +180,7 @@ Imlib_init(Display * disp)
   homedir = getenv("HOME");
   snprintf(s, sizeof(s), "%s/.imrc", homedir);
 
+  setlocale(LC_ALL, "C");
   f = fopen(s, "r");
   if (!f)
     f = fopen(SYSTEM_IMRC, "r");
@@ -347,6 +349,7 @@ Imlib_init(Display * disp)
 	}
       fclose(f);
     }
+  setlocale(LC_ALL, "");
   /* list all visuals for the default screen */
   xvi.screen = id->x.screen;
   xvir = XGetVisualInfo(disp, VisualScreenMask, &xvi, &num);
@@ -714,6 +717,7 @@ Imlib_init_with_params(Display * disp, ImlibInitParams * p)
   id->num_colors = 0;
   homedir = getenv("HOME");
   snprintf(s, sizeof(s), "%s/.imrc", homedir);
+  setlocale(LC_ALL, "C");
   f = fopen(s, "r");
   if (!f)
     f = fopen(SYSTEM_IMRC, "r");
@@ -882,6 +886,7 @@ Imlib_init_with_params(Display * disp, ImlibInitParams * p)
 	}
       fclose(f);
     }
+  setlocale(LC_ALL, "");
   if (p)
     {
       if (p->flags & PARAMS_VISUALID)
