@@ -3,6 +3,7 @@
 #include "gdk_imlib.h"
 #define id _gdk_imlib_data
 #include "gdk_imlib_private.h"
+#include <locale.h>
 
 char                x_error;
 
@@ -232,6 +233,7 @@ gdk_imlib_init()
   id->num_colors = 0;
   homedir = getenv("HOME");
   g_snprintf(s, sizeof(s), "%s/.imrc", homedir);
+  setlocale(LC_ALL, "C");
   f = fopen(s, "r");
   if (!f)
     f = fopen(SYSTEM_IMRC, "r");
@@ -400,6 +402,7 @@ gdk_imlib_init()
 	}
       fclose(f);
     }
+  setlocale(LC_ALL, "");
   /* list all visuals for the default screen */
   xvi.screen = id->x.screen;
   xvir = XGetVisualInfo(disp, VisualScreenMask, &xvi, &num);
@@ -720,6 +723,7 @@ gdk_imlib_init_params(GdkImlibInitParams * p)
   id->num_colors = 0;
   homedir = getenv("HOME");
   g_snprintf(s, sizeof(s), "%s/.imrc", homedir);
+  setlocale(LC_ALL, "C");
   f = fopen(s, "r");
   if (!f)
     f = fopen(SYSTEM_IMRC, "r");
@@ -888,6 +892,7 @@ gdk_imlib_init_params(GdkImlibInitParams * p)
 	}
       fclose(f);
     }
+  setlocale(LC_ALL, "");
   if (p)
     {
       if (p->flags & PARAMS_VISUALID)
